[openssh-commits] [openssh] 01/01: Typo fixes in error messages.

git+noreply at mindrot.org git+noreply at mindrot.org
Sat Jun 8 00:51:32 AEST 2019


This is an automated email from the git hooks/post-receive script.

dtucker pushed a commit to branch master
in repository openssh.

commit fc0340f7c4ee29bfb12bd1de9f99defa797e16b4
Author: Darren Tucker <dtucker at dtucker.net>
Date:   Sat Jun 8 00:10:59 2019 +1000

    Typo fixes in error messages.
    
    Patch from knweiss at gmail.com via github pull req #97 (portable-
    specific parts).
---
 auth-pam.c | 6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

diff --git a/auth-pam.c b/auth-pam.c
index c0504fd0..55253e6a 100644
--- a/auth-pam.c
+++ b/auth-pam.c
@@ -258,7 +258,7 @@ static char **
 pam_getenvlist(pam_handle_t *pamh)
 {
 	/*
 	 * XXX - If necessary, we can still support envrionment passing
 	 * for platforms without pam_getenvlist by searching for known
 	 * env vars (e.g. KRB5CCNAME) from the PAM environment.
 	 */
@@ -541,7 +541,7 @@ sshpam_thread(void *ctxtp)
 	for (i = 0; environ[i] != NULL; i++) {
 		/* Count */
 		if (i > INT_MAX)
-			fatal("%s: too many enviornment strings", __func__);
+			fatal("%s: too many environment strings", __func__);
 	}
 	if ((r = sshbuf_put_u32(buffer, i)) != 0)
 		fatal("%s: buffer error: %s", __func__, ssh_err(r));
@@ -554,7 +554,7 @@ sshpam_thread(void *ctxtp)
 	for (i = 0; env_from_pam != NULL && env_from_pam[i] != NULL; i++) {
 		/* Count */
 		if (i > INT_MAX)
-			fatal("%s: too many PAM enviornment strings", __func__);
+			fatal("%s: too many PAM environment strings", __func__);
 	}
 	if ((r = sshbuf_put_u32(buffer, i)) != 0)
 		fatal("%s: buffer error: %s", __func__, ssh_err(r));
@@ -258,7 +258,7 @@ static char **
 {
 	/*
-	 * XXX - If necessary, we can still support envrionment passing
+	 * XXX - If necessary, we can still support environment passing
 	 * for platforms without pam_getenvlist by searching for known
 	 * env vars (e.g. KRB5CCNAME) from the PAM environment.

-- 
To stop receiving notification emails like this one, please contact
djm at mindrot.org.


More information about the openssh-commits mailing list